@@ -1,5 +1,5 @@
-from config import weather_url_start,api_key,weather_url_end
-from transformer import OutputTransformer
+from .config import weather_url_start,api_key,weather_url_end
+from .transformer import OutputTransformer
 import requests
 import json
 import concurrent.futures
